==> bynder-8.x-1.1.tar.gz: bynder/src/BynderApi.php <==
<?php

namespace Drupal\bynder;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Bynder\Api\BynderApiFactory;
use Drupal\Core\State\StateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Session\SessionInterface;

/**
 * Bynder API service.
 *
 * @method array getBrands()
 * @method array getMediaList(array $query)
 * @method array getMediaInfo(string $media_id, int $versions)
 * @method array getMetaproperties()
 * @method array getTags()
 * @method array uploadFileAsync(array $data)
 *
 * @package Drupal\bynder
 */
class BynderApi implements BynderApiInterface {

  /**
   * Bynder configuration.
   *
   * Contains array with keys consumer_key, consumer_secret, token, token_secret
   * and account_domain.
   *
   * @var array
   */
  protected $bynderConfig;

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactory
   */
  protected $loggerFactory;

  /**
   * The active session.
   *
   * @var \Symfony\Component\HttpFoundation\Session\SessionInterface
   */
  protected $session;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * BynderApi constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger factory.
   * @param \Symfony\Component\HttpFoundation\Session\SessionInterface $session
   *   The session service.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LoggerChannelFactoryInterface $logger_factory, SessionInterface $session, StateInterface $state) {
    $this->configFactory = $config_factory;
    $this->loggerFactory = $logger_factory;
    $this->session = $session;
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public function getAssetBankManager() {
    if ($this->bynderConfig) {
      $bynder_configuration = [
        'consumerKey' => $this->bynderConfig['consumerKey'],
        'consumerSecret' => $this->bynderConfig['consumerSecret'],
        'token' => $this->bynderConfig['token'],
        'tokenSecret' => $this->bynderConfig['tokenSecret'],
        'baseUrl' => $this->bynderConfig['baseUrl'],
      ];
    }
    else {
      $bynder_settings = $this->configFactory->get('bynder.settings');
      $bynder_configuration = [
        'consumerKey' => $bynder_settings->get('consumer_key'),
        'consumerSecret' => $bynder_settings->get('consumer_secret'),
        'token' => $bynder_settings->get('token'),
        'tokenSecret' => $bynder_settings->get('token_secret'),
        'baseUrl' => $bynder_settings->get('account_domain'),
      ];

      // @TODO Re-evaluate where global and where user token is used.
      $session_data = \Drupal::service('session')->get('bynder', []);
      if (!empty($session_data['access_token']) && !empty($session_data['config_hash']) && $session_data['config_hash'] == $this->state->get('bynder_config_hash')) {
        $bynder_configuration['token'] = $session_data['access_token']['oauth_token'];
        $bynder_configuration['tokenSecret'] = $session_data['access_token']['oauth_token_secret'];
      }
    }

    $bynder_api = BynderApiFactory::create($bynder_configuration);

    return $bynder_api->getAssetBankManager();
  }

  /**
   * {@inheritdoc}
   */
  public function initiateOAuthTokenRetrieval() {
    $bynder_settings = $this->configFactory->get('bynder.settings');
    $bynder_configuration = [
      'consumerKey' => $bynder_settings->get('consumer_key'),
      'consumerSecret' => $bynder_settings->get('consumer_secret'),
      'baseUrl' => $bynder_settings->get('account_domain'),
    ];

    // @TODO statically cache api object?
    $bynder_api = BynderApiFactory::create($bynder_configuration);

    $session_data = $this->session->get('bynder', []);
    foreach (explode('&', $bynder_api->getRequestToken()->wait()) as $item) {
      $value = explode('=', $item);
      $session_data['request_token'][$value[0]] = $value[1];
    }
    $this->session->set('bynder', $session_data);

    $callback = Url::fromRoute('bynder.oauth', [], ['absolute' => TRUE])
      ->toString(TRUE)
      ->getGeneratedUrl();
    $response = $bynder_api->authoriseRequestToken(['oauth_token' => $session_data['request_token']['oauth_token'], 'callback' => $callback])->wait();
    return Url::fromUri($bynder_settings->get('account_domain') . $response->getHeader('Location')[0]);
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccessToken() {
    $session_data = $this->session->get('bynder', []);

    // Required tokens need to be stored in the session.
    if (empty($session_data['access_token']['oauth_token']) || empty($session_data['access_token']['oauth_token_secret'])) {
      return FALSE;
    }

    // In case of the global config change all user sessions need to expire.
    if (empty($session_data['config_hash']) || $session_data['config_hash'] != $this->state->get('bynder_config_hash')) {
      return FALSE;
    }

    // Try to connect to see if the token is really valid.
    $able_to_connect = TRUE;
    try {
      $this->getBrands();
    }
    catch (\Exception $e) {
      $able_to_connect = FALSE;
    }

    return $able_to_connect;
  }

  /**
   * {@inheritdoc}
   */
  public function finishOAuthTokenRetrieval(Request $request) {
    $bynder_settings = $this->configFactory->get('bynder.settings');
    $session_data = $this->session->get('bynder', []);
    $bynder_configuration = [
      'consumerKey' => $bynder_settings->get('consumer_key'),
      'consumerSecret' => $bynder_settings->get('consumer_secret'),
      'token' => $request->query->get('oauth_token'),
      'tokenSecret' => $session_data['request_token']['oauth_token_secret'],
      'baseUrl' => $bynder_settings->get('account_domain'),
    ];

    // @TODO Statically cache API object?
    $bynder_api = BynderApiFactory::create($bynder_configuration);

    foreach ($bynder_api->getAccessToken()->wait() as $key => $item) {
      $session_data['access_token'][$key] = $item;
    }
    unset($session_data['request_token']);
    $session_data['config_hash'] = $this->state->get('bynder_config_hash');
    $this->session->set('bynder', $session_data);
  }

  /**
   * Sets the Bynder configuration.
   *
   * @param array $config
   *   Array with keys consumer_key, consumer_secret, token, token_secret and
   *   account_domain.
   */
  public function setBynderConfiguration(array $config) {
    $this->bynderConfig = $config;
  }

  /**
   * {@inheritdoc}
   */
  public function __call($method, $args) {
    $bynder_configuration = $this->configFactory->get('bynder.settings');
    if ($bynder_configuration->get('debug')) {
      $this->loggerFactory->get('bynder')->debug('Method: %method is called with arguments: @args', [
        '%method' => $method,
        '@args' => print_r($args, TRUE),
      ]);
    }
    try {
      $result = call_user_func_array([$this->getAssetBankManager(), $method], $args)->wait();
      if ($bynder_configuration->get('debug')) {
        $this->loggerFactory->get('bynder')->debug('Method: %method returns: @result', [
          '%method' => $method,
          '@result' => print_r($result, TRUE),
        ]);
      }
      return $result;
    }
    catch (\Exception $e) {
      if ($bynder_configuration->get('debug')) {
        $this->loggerFactory->get('bynder')->error('Method: %method throws error with message: @message', [
          '%method' => $method,
          '@message' => $e->getMessage(),
        ]);
      }
      throw $e;
    }
  }

}

==> bynder-8.x-1.3.tar.gz: bynder/src/BynderApi.php <==
<?php

namespace Drupal\bynder;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Bynder\Api\BynderApiFactory;
use Drupal\Core\State\StateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Session\SessionInterface;

/**
 * Bynder API service.
 *
 * @method array getBrands()
 * @method array getMediaList(array $query)
 * @method array getMediaInfo(string $media_id, int $versions)
 * @method array getMetaproperties(array $query)
 * @method array getTags()
 * @method array uploadFileAsync(array $data)
 * @method array getDerivatives()
 *
 * @package Drupal\bynder
 */
class BynderApi implements BynderApiInterface {

  /**
   * Bynder Api instance.
   *
   * @var \Bynder\Api\BynderApiFactory
   */
  protected $bynderApi;
  /**
   * Bynder configuration.
   *
   * Contains array with keys consumer_key, consumer_secret, token, token_secret
   * and account_domain.
   *
   * @var array
   */
  protected $bynderConfig;

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The logger factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactory
   */
  protected $loggerFactory;

  /**
   * The active session.
   *
   * @var \Symfony\Component\HttpFoundation\Session\SessionInterface
   */
  protected $session;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * BynderApi constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger factory.
   * @param \Symfony\Component\HttpFoundation\Session\SessionInterface $session
   *   The session service.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LoggerChannelFactoryInterface $logger_factory, SessionInterface $session, StateInterface $state) {
    $this->configFactory = $config_factory;
    $this->loggerFactory = $logger_factory;
    $this->session = $session;
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public function initiateOAuthTokenRetrieval() {
    $bynder_settings = $this->configFactory->get('bynder.settings');
    $bynder_configuration = [
      'consumerKey' => $bynder_settings->get('consumer_key'),
      'consumerSecret' => $bynder_settings->get('consumer_secret'),
      'baseUrl' => $bynder_settings->get('account_domain'),
    ];

    $this->bynderApi = BynderApiFactory::create($bynder_configuration);

    $session_data = $this->session->get('bynder', []);
    foreach (explode('&', $this->bynderApi->getRequestToken()->wait()) as $item) {
      $value = explode('=', $item);
      $session_data['request_token'][$value[0]] = $value[1];
    }
    $this->session->set('bynder', $session_data);

    $callback = Url::fromRoute('bynder.oauth', [], ['absolute' => TRUE])
      ->toString(TRUE)
      ->getGeneratedUrl();
    $response = $this->bynderApi->authoriseRequestToken(['oauth_token' => $session_data['request_token']['oauth_token'], 'callback' => $callback])->wait();
    return Url::fromUri($bynder_settings->get('account_domain') . $response->getHeader('Location')[0]);
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccessToken() {
    $session_data = $this->session->get('bynder', []);

    // Required tokens need to be stored in the session.
    if (empty($session_data['access_token']['oauth_token']) || empty($session_data['access_token']['oauth_token_secret'])) {
      return FALSE;
    }

    // In case of the global config change all user sessions need to expire.
    if (empty($session_data['config_hash']) || $session_data['config_hash'] != $this->state->get('bynder_config_hash')) {
      return FALSE;
    }

    // Try to connect to see if the token is really valid.
    $able_to_connect = TRUE;
    try {
      $this->getBrands();
    }
    catch (\Exception $e) {
      $able_to_connect = FALSE;
    }

    return $able_to_connect;
  }

  /**
   * {@inheritdoc}
   */
  public function finishOAuthTokenRetrieval(Request $request) {
    $bynder_settings = $this->configFactory->get('bynder.settings');
    $session_data = $this->session->get('bynder', []);
    $bynder_configuration = [
      'consumerKey' => $bynder_settings->get('consumer_key'),
      'consumerSecret' => $bynder_settings->get('consumer_secret'),
      'token' => $request->query->get('oauth_token'),
      'tokenSecret' => $session_data['request_token']['oauth_token_secret'],
      'baseUrl' => $bynder_settings->get('account_domain'),
    ];

    // @TODO Statically cache API object?
    $this->bynderApi = BynderApiFactory::create($bynder_configuration);

    foreach ($this->bynderApi->getAccessToken()->wait() as $key => $item) {
      $session_data['access_token'][$key] = $item;
    }
    unset($session_data['request_token']);
    $session_data['config_hash'] = $this->state->get('bynder_config_hash');
    $this->session->set('bynder', $session_data);
  }

  public function hasUploadPermissions()
  {
      $user = $this->bynderApi->getCurrentUser()->wait();
      if (isset($user)) {
          $profileId = $user['profileId'];
          $userProfile = $this->bynderApi->getSecurityProfile($profileId)->wait();
          foreach ($userProfile['roles'] as $role) {
              if ($role == 'MEDIAUPLOAD' || $role == 'MEDIAUPLOADFORAPPROVAL') {
                  return $role;
              }
          }
      }
      return false;
  }

 /**
   * {@inheritdoc}
   */
  public function getAssetBankManager() {
    if ($this->bynderConfig) {
      $bynder_configuration = [
        'consumerKey' => $this->bynderConfig['consumerKey'],
        'consumerSecret' => $this->bynderConfig['consumerSecret'],
        'token' => $this->bynderConfig['token'],
        'tokenSecret' => $this->bynderConfig['tokenSecret'],
        'baseUrl' => $this->bynderConfig['baseUrl'],
      ];
    }
    else {
      $bynder_settings = $this->configFactory->get('bynder.settings');
      $bynder_configuration = [
        'consumerKey' => $bynder_settings->get('consumer_key'),
        'consumerSecret' => $bynder_settings->get('consumer_secret'),
        'token' => $bynder_settings->get('token'),
        'tokenSecret' => $bynder_settings->get('token_secret'),
        'baseUrl' => $bynder_settings->get('account_domain'),
      ];

      // @TODO Re-evaluate where global and where user token is used.
      $session_data = \Drupal::service('session')->get('bynder', []);
      if (!empty($session_data['access_token']) && !empty($session_data['config_hash']) && $session_data['config_hash'] == $this->state->get('bynder_config_hash')) {
        $bynder_configuration['token'] = $session_data['access_token']['oauth_token'];
        $bynder_configuration['tokenSecret'] = $session_data['access_token']['oauth_token_secret'];
      }
    }
    $this->bynderApi = BynderApiFactory::create($bynder_configuration);

    return $this->bynderApi->getAssetBankManager();
  }
  
  /**
   * Sets the Bynder configuration.
   *
   * @param array $config
   *   Array with keys consumer_key, consumer_secret, token, token_secret and
   *   account_domain.
   */
  public function setBynderConfiguration(array $config) {
    $this->bynderConfig = $config;
  }


  /**
   * {@inheritdoc}
   */
  public function __call($method, $args) {
    $bynder_configuration = $this->configFactory->get('bynder.settings');
    if ($bynder_configuration->get('debug')) {
      $this->loggerFactory->get('bynder')->debug('Method: %method is called with arguments: @args', [
        '%method' => $method,
        '@args' => print_r($args, TRUE),
      ]);
    }
    try {
      $result = call_user_func_array([$this->getAssetBankManager(), $method], $args)->wait();
      if ($bynder_configuration->get('debug')) {
        $this->loggerFactory->get('bynder')->debug('Method: %method returns: @result', [
          '%method' => $method,
          '@result' => print_r($result, TRUE),
        ]);
      }
      return $result;
    }
    catch (\Exception $e) {
      if ($bynder_configuration->get('debug')) {
        $this->loggerFactory->get('bynder')->error('Method: %method throws error with message: @message', [
          '%method' => $method,
          '@message' => $e->getMessage(),
        ]);
      }
      throw $e;
    }
  }

}
